@@ -20,7 +20,9 @@ package POE::Component::Client::MPD::Commands;
 use strict;
 use warnings;
 
-use POE  qw[ Component::Client::MPD::Message ];
+use POE;
+use POE::Component::Client::MPD::Message;
+use POE::Component::Client::MPD::Stats;
 use base qw[ Class::Accessor::Fast ];
 
 # -- MPD interaction: general commands
@@ -87,7 +89,7 @@ sub _onpub_output_disable {
 #
 # event: stats()
 #
-# Return a POCOCM::Stats object with the current statistics of MPD.
+# Return a hash with the current statistics of MPD.
 #
 sub _onpub_stats {
     my $msg = POE::Component::Client::MPD::Message->new( {
@@ -96,11 +98,27 @@ sub _onpub_stats {
         _answer   => $SEND,
         _commands => [ 'stats' ],
         _cooking  => $AS_KV,
+        _post     => '_stats_postback',
     } );
     $_[KERNEL]->yield( '_send', $msg );
 }
 
 
+#
+# event: _stats_postback( $msg )
+#
+# Transform $msg->data from hash to a POCOCM::Stats object with the current
+# statistics of MPD.
+#
+sub _onpriv_stats_postback {
+    my $msg   = $_[ARG0];
+    my %stats = @{ $msg->data };
+    my $stats = POE::Component::Client::MPD::Stats->new( \%stats );
+    $msg->data($stats);
+    $_[KERNEL]->yield( '_mpd_data', $msg );
+}
+
+
 # -- MPD interaction: altering settings
 # -- MPD interaction: controlling playback
 
